"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var path_1 = __importDefault(require("path"));
var fs_1 = __importDefault(require("fs"));
var webpack_1 = __importDefault(require("webpack"));
var html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
var mini_css_extract_plugin_1 = __importDefault(require("mini-css-extract-plugin"));
var fork_ts_checker_webpack_plugin_1 = __importDefault(require("fork-ts-checker-webpack-plugin"));
var utils_1 = __importDefault(require("./utils"));
function hasTSConfig() {
    return fs_1.default.existsSync(path_1.default.resolve(process.cwd(), 'tsconfig.json'));
}
function addPlugins(basePlugins, plugins) {
    if (plugins) {
        plugins.forEach(function (plugin) {
            basePlugins.push(plugin);
        });
    }
    return basePlugins;
}
function getPlugins() {
    var basePlugins = [
        new html_webpack_plugin_1.default({
            template: path_1.default.resolve(process.cwd(), './public/index.html'),
            multiStep: true
        }),
        new webpack_1.default.DefinePlugin({
            'process.env': {
                NODE_ENV: JSON.stringify(utils_1.default.getEnv())
            }
        })
    ];
    if (hasTSConfig()) {
        basePlugins.push(new fork_ts_checker_webpack_plugin_1.default({ async: false }));
    }
    if (utils_1.default.isDev()) {
        addPlugins(basePlugins, [
            new webpack_1.default.HotModuleReplacementPlugin(),
            new mini_css_extract_plugin_1.default({
                filename: 'css/[name].css'
            })
        ]);
    }
    if (utils_1.default.isProduction()) {
        addPlugins(basePlugins, [
            new mini_css_extract_plugin_1.default({
                filename: 'css/[name].[hash:8].css'
            })
        ]);
    }
    return basePlugins;
}
exports.default = getPlugins;
;
